.. _spkg_nibabel:

nibabel: Access a multitude of neuroimaging data formats
========================================================

Description
-----------

Access a multitude of neuroimaging data formats

License
-------

MIT License

Upstream Contact
----------------

https://pypi.org/project/nibabel/



Type
----

optional


Dependencies
------------

- $(PYTHON)
- $(PYTHON_TOOLCHAIN)

Version Information
-------------------

requirements.txt::

    nibabel

Equivalent System Packages
--------------------------

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install nibabel

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-nibabel

.. tab:: MacPorts:

   .. CODE-BLOCK:: bash

       $ sudo port install py-nibabel

.. tab:: openSUSE:

   .. CODE-BLOCK:: bash

       $ sudo zypper install python3\$\{PYTHON_MINOR\}-nibabel

# See https://repology.org/project/nibabel/versions, https://repology.org/project/python:nibabel/versions

If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then ``./configure`` will check if the system package can be used.
